import type {
  AddBannerConfigType,
  BackSysIndustryListType,
  EntityNameAndCodeListType,
  FootConfigDetailType,
} from './middleground.type';
import { request, type RequestOptions } from '@/utils/request';

/**
 *
 * 获取 行业列表
 * @export
 * @param {RequestOptions} [options]
 * @return {*}
 */
export async function getBackSysIndustry(
  options?: RequestOptions,
): Promise<BackSysIndustryListType[]> {
  return request<BackSysIndustryListType[]>('/api/forward/middleground/getBackSysIndustry', {
    method: 'GET',
    ...(options || {}),
  });
}

/**
 *
 * 根据公司名称查询对应公司名称和信用编码
 * @export
 * @param {RequestOptions} [options]
 * @return {*}
 */
export async function getEntityNameAndCode(
  params,
  options?: RequestOptions,
): Promise<EntityNameAndCodeListType> {
  return request<EntityNameAndCodeListType>('/api/forward/middleground/getentitynameandcode', {
    method: 'GET',
    params,
    ...(options || {}),
  });
}

/**
 *
 * 新增轮播图
 * @export
 * @param {RequestOptions} [options]
 * @return {*}
 */
export async function addBannerConfig(
  body,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/bannerConfig/add', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}

export async function listBannerConfig(
  params,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/page/bannerConfig/list', {
    method: 'GET',
    params: {
      ...params,
    },
    ...(options || {}),
  });
}

export async function putBannerConfig(
  body,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/bannerConfig/edit', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}
export async function delBannerConfig(id, options?: RequestOptions): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/bannerConfig/delete?ids=' + id, {
    method: 'GET',
    ...(options || {}),
  });
}

/**
 *
 * 新增轮播图
 * @export
 * @param {RequestOptions} [options]
 * @return {*}
 */
export async function addArticleConfig(
  body,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/article/add', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}

export async function listArticleConfig(
  params,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/page/article/list', {
    method: 'GET',
    params: {
      ...params,
    },
    ...(options || {}),
  });
}

export async function putArticleConfig(
  body,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/article/edit', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}
export async function delArticleConfig(id, options?: RequestOptions): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/middleground/article/delete?ids=' + id, {
    method: 'GET',
    ...(options || {}),
  });
}

export async function listFootConfig(
  params,
  options?: RequestOptions,
): Promise<AddBannerConfigType> {
  return request<AddBannerConfigType>('/api/forward/page/footConfig/list', {
    method: 'GET',
    params: {
      ...params,
    },
    ...(options || {}),
  });
}

export async function detailFootConfig(options?: RequestOptions): Promise<FootConfigDetailType> {
  return request<FootConfigDetailType>('/api/forward/middleground/footConfig/detail', {
    method: 'GET',
    ...(options || {}),
  });
}

export async function addFooterConfig(
  body,
  options?: RequestOptions,
): Promise<FootConfigDetailType> {
  return request<FootConfigDetailType>('/api/forward/middleground/footConfig/add', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}

export async function putFooterConfig(
  body,
  options?: RequestOptions,
): Promise<FootConfigDetailType> {
  return request<FootConfigDetailType>('/api/forward/middleground/footConfig/edit', {
    method: 'POST',
    data: body,
    headers: {
      'Content-Type': 'application/json',
    },
    ...(options || {}),
  });
}
