// src/api/invoice.ts
//import axios from '@/utils/request';
import axios from 'axios';
import type { InvoiceCreateParams } from '@/types/invoice';
import { request, type RequestOptions } from '@/utils/request.ts';

export const InvoiceService = {
  /**
   * 上传发票文件 --  废弃
   */
  async uploadFile(file: File) {
    const formData = new FormData();
    formData.append('file', file);

    const response = await axios.post<{
      url: string;
      fileName: string;
      fileSize: number;
    }>('/api/eweiShopMemberInvoice/upload', formData, {
      headers: {
        'Content-Type': 'multipart/form-data',
      },
    });

    return response.data;
  },

  /**
   * 创建发票记录
   */
  async create(data: InvoiceCreateParams, options?: RequestOptions) {
    return request<any>('/api/forward/middleground/eweiShopMemberInvoice/add', {
      method: 'POST',
      data: data,
      ...(options || { successMsg: '新增成功' }),
    });
    //const response = await axios.post<InvoiceRecord>('/api/forward/middleground/eweiShopMemberInvoice/add', data);
    //return response.data;
  },

  /**
   * 更新发票记录
   */
  async update(id: number, data: Partial<InvoiceCreateParams>, options?: RequestOptions) {
    return request<any>('/api/forward/middleground/eweiShopMemberInvoice/edit', {
      method: 'POST',
      data: data,
      ...(options || { successMsg: '更新成功' }),
    });
    //const response = await axios.post<InvoiceRecord>(`/api/forward/middleground/eweiShopMemberInvoice/edit`, data);
    //return response.data;
  },

  /**
   * 删除发票记录
   */
  async delete(id: string, options?: RequestOptions) {
    return request<any>('/api/forward/middleground/eweiShopMemberInvoice/del?id=' + id, {
      method: 'GET',
      ...(options || { successMsg: '删除成功' }),
    });
    // await axios.get(`/api/forward/middleground/eweiShopMemberInvoice/del?id=${id}`);
    // return true;
  },

  /**
   * 获取发票记录列表
   */
  // async getList(params: {
  //     memberId?: string;
  //     pageSize: number;
  //     pageNum: number;
  // }) {
  //     const { pageNum:page } = params
  //     const response = await axios.get<InvoiceRecord[]>('/api/forward/page/eweiShopMemberInvoice/list', { params:{ ...params, page } });
  //     return response.data;
  // },
  async getList(
    params: {
      memberId?: string;
      pageSize: number;
      pageNum: number;
    },
    options?: RequestOptions,
  ) {
    const { pageNum: page } = params;
    return request<any>('/api/forward/page/eweiShopMemberInvoice/list', {
      method: 'GET',
      params: { ...params, page },
      ...(options || {}),
    });
  },

  /**
   * 获取单条发票记录详情
   */
  async getDetail(id: number, options?: RequestOptions) {
    return request<any>('/api/forward/middleground/eweiShopMemberInvoice/detail?id=' + id, {
      method: 'GET',
      ...(options || {}),
    });

    // const response = request<any>(`/api/forward/middleground/eweiShopMemberInvoice/detail?id=${id}`,{
    //     method: 'GET',
    // ...(options || {}),
    // });
    // return response.data;
  },

  /**
   * 下载发票文件
   */
  async downloadFile(_id: string) {
    /* const response = await axios.get<Blob>(`/api/eweiShopMemberInvoice/${id}/download`, {
             responseType: 'blob'
         });

         return {
             data: response.data,
             fileName: decodeURIComponent(
                 response.headers['content-disposition']?.split('filename=')[1] || `invoice_${id}.pdf`
             )
         };*/
  },

  /**
   * 获取发票预览地址
   */
  getPreviewUrl(id: string) {
    return `${axios.defaults.baseURL}/api/eweiShopMemberInvoice/${id}/preview`;
  },
};
