import OSS from 'ali-oss';
import type { UploadFile, UploadProps } from 'ant-design-vue';
import { baseApiUrl } from '@/utils/request';
import Api from '@/api';

type FileType = Parameters<NonNullable<UploadProps['beforeUpload']>>[0];

export const useImageUploadHooks = () => {
  /**
   *
   * 获取图片地址
   * @param {string} path
   * @return {*}
   */
  const getImageUrl = (path: string) => {
    return /^https?:\/\//.test(path) ? path : baseApiUrl + path;
  };

  /**
   *
   * 上传文件到oss服务器
   */
  const uploadOss = async (file: FileType | File) => {
    const type = file.name.split('.')[1];
    const name = `${new Date().getTime()}${file.size}.${type}`;
    const { accessKeyId, accessKeySecret, region, securityToken, bucket } =
      await Api.toolsUpload.uploadGetStsToken();

    const client = new OSS({
      region: region,
      accessKeyId,
      accessKeySecret,
      stsToken: securityToken,
      bucket: bucket,
      protocol: 'https',
    });
    const result = await client.put(name, file);
    return result.url;
  };

  /**
   *
   * 打开新页面预览
   */
  const filePreview = (url) => {
    const handle = window.open(url, 'filepreview', 'popup');
    if (!handle) {
      // message.error('请允许新窗口打开');
      const link = document.createElement('a');
      link.href = url;
      link.target = '_blank';
      link.style.display = 'none';
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    }
  };

  /**
   *
   * 获取file后缀
   */
  const getFileSuffix = (file) => {
    const match = file.name.match(/\.([^.]+)$/);
    const type = match ? match[1] : '';
    return type;
  };

  /**
   *
   * 判断是否是图片文件
   */
  const isImageFile = (file: FileType | UploadFile) => {
    const suffix = getFileSuffix(file);
    const type = file.type;
    return (
      (type && /^image/.test(type)) ||
      suffix === 'png' ||
      suffix === 'jpg' ||
      suffix === 'jpeg' ||
      suffix === 'ico' ||
      suffix === 'gif'
    );
  };

  return {
    getImageUrl,
    uploadOss,
    filePreview,
    getFileSuffix,
    isImageFile,
  };
};
