import { Image, Tag } from 'ant-design-vue';
import type { TableColumn } from '@/components/core/dynamic-table';
import type { ClientAdvertDto } from './type.ts';
import { getAvatarUrl } from '@/views/system/user/columns.tsx';

export type TableListItem = ClientAdvertDto;
export type TableColumnItem = TableColumn<TableListItem>;

export const baseColumns: TableColumnItem[] = [
  {
    title: '广告轮播图',
    dataIndex: 'imageUrl',
    width: 180,
    hideInSearch: true,
    customRender: ({ record }) => (
      <Image width={100} height={80} src={getAvatarUrl(record.imageUrl)} />
    ),
  },
  {
    title: '跳转链接',
    dataIndex: 'linkUrl',
    width: 180,
    ellipsis: true,
    hideInSearch: true,
  },
  {
    title: '说明',
    width: 180,
    dataIndex: 'remark',
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 80,
    formItemProps: {
      component: 'Select',
      componentProps: {
        options: [
          {
            label: '启用',
            value: 1,
          },
          {
            label: '禁用',
            value: 0,
          },
        ],
      },
    },
    customRender: ({ record }) => {
      const enable = ~~record.status === 1;
      return <Tag color={enable ? 'green' : 'red'}>{enable ? '启用' : '停用'}</Tag>;
    },
  },
];
