import { computed } from 'vue';
import { Select } from 'ant-design-vue';
import type { FormSchema } from '@/components/core/schema-form/';
import type { ClientAdvertDto } from './type.ts';
import AvatarUpload from '@/components/basic/image-upload/ImageUpload.vue';
import { useDictStore } from '@/store/modules/dict';
const { dictData } = useDictStore();

const advertType = computed(() => dictData['advert_type']);
const advertLinkType = computed(() => dictData['advert_link_type']);
const positionType = computed(() => dictData['advert_position']);

type FormType = {
  industry: {
    label: string;
    value: string;
  };
  companyAndCode: {
    label: string;
    value: string;
  };
};

export const userSchemas: FormSchema<ClientAdvertDto & FormType>[] = [
  {
    field: 'type',
    label: '类型',
    rules: [{ required: true, trigger: 'blur', message: '请选择类型' }],
    defaultValue: 1,
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请选择类型"
          v-model:value={formModel.type}
          options={advertType.value.map((item) => {
            return {
              label: item.label,
              value: Number(item.value),
            };
          })}
        ></Select>
      );
    },
  },
  {
    field: 'remark',
    component: 'Input',
    label: '广告说明',
    rules: [{ required: true, trigger: 'blur', message: '请填写广告说明' }],
  },
  {
    field: 'imageUrl',
    component: () => AvatarUpload,
    label: '广告轮播图',
    rules: [{ required: true, trigger: 'blur', message: '请上传图片' }],
  },
  {
    field: 'linkType',
    label: '链接类型',
    rules: [{ required: true, trigger: 'blur', message: '请选择链接类型' }],
    defaultValue: 1,
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请选择类型"
          v-model:value={formModel.linkType}
          options={advertLinkType.value.map((item) => {
            return {
              label: item.label,
              value: Number(item.value),
            };
          })}
        ></Select>
      );
    },
  },
  {
    field: 'linkUrl',
    component: 'Input',
    label: '链接地址',
  },
  {
    field: 'position',
    label: '广告位置',
    rules: [{ required: true, trigger: 'blur', message: '请选择广告位置' }],
    defaultValue: 1,
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请选择类型"
          label-in-value
          fieldNames={{
            label: 'label',
            value: 'value',
          }}
          value={formModel.position}
          options={positionType.value}
          onChange={(val: { value: string; label: string }) => {
            formModel.position = val?.value;
          }}
        ></Select>
      );
    },
  },

  {
    field: 'status',
    label: '状态',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '启用',
          value: 1,
        },
        {
          label: '禁用',
          value: 0,
        },
      ],
    },
  },

  {
    field: 'sort',
    component: 'InputNumber',
    label: '排序',
    defaultValue: 100,
    componentProps: {
      style: {
        width: '100%',
      },
    },
  },
];
