import { computed } from 'vue';
import { Select, Spin } from 'ant-design-vue';
import { useCustomerListHooks } from './hooks';
import type { FormSchema } from '@/components/core/schema-form/';
import type { SelectValue } from 'ant-design-vue/es/select';
import { useCommonCacheStore } from '@/store/modules/commonCache';
const { commonCacheData } = useCommonCacheStore();

const { entityNameState, fetchEntityName } = useCustomerListHooks();
const backSysIndustry = computed(() => commonCacheData['backSysIndustry']);
type FormType = {
  industry: {
    label: string;
    value: string;
  };
  companyAndCode: {
    label: string;
    value: string;
  };
};

export const userSchemas: FormSchema<API.ClientUserDto & FormType>[] = [
  // {
  //   field: 'username',
  //   component: 'Input',
  //   label: '用户名',
  //   rules: [{ required: true, trigger: 'blur' }],
  // },
  {
    field: 'nickname',
    component: 'Input',
    label: '联系人',
    rules: [{ required: true, trigger: 'blur' }],
  },
  {
    field: 'phone',
    component: 'Input',
    label: '手机',
    rules: [
      { required: true, trigger: 'blur' },
      {
        pattern: /^1[3456789]\d{9}$/,
        message: '手机号格式不正确',
      },
    ],
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    componentProps: {
      placeholder: '无需修改请留空',
    },
  },

  {
    field: 'companyAndCode',
    label: '登记企业',
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请输入登记企业"
          label-in-value
          filter-option={false}
          not-found-content={entityNameState.fetching ? undefined : null}
          options={entityNameState.data}
          default-active-first-option={false}
          value={
            {
              key: formModel.companyAndCode?.value || '',
              value: formModel.companyAndCode?.value || '',
              label: formModel.companyAndCode?.label || '',
            } as unknown as SelectValue
          }
          onSearch={fetchEntityName}
          showSearch
          // allowClear={false}
          onChange={(val: { value: string; label: string }) => {
            formModel.creditCode = val?.value || '';
            formModel.company = val?.label || '';
            entityNameState.value = val;
          }}
          v-slots={{
            notFoundContent: () => (entityNameState.fetching ? <Spin size="small" /> : null),
          }}
        ></Select>
      );
    },
    transform(data) {
      const { originLabel, value, label } = data || {};
      return { creditCode: value || '', company: originLabel || label || '' };
    },
    // componentProps:{

    // }
  },
  {
    field: 'office',
    component: 'Input',
    label: '职务',
    componentProps: {
      // allowClear: false,
    },
  },
  {
    field: 'industry',
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请选择关注领域"
          label-in-value
          fieldNames={{
            label: 'name',
            value: 'id',
          }}
          value={formModel.industry}
          options={backSysIndustry.value}
          onChange={(val: { value: string; label: string }) => {
            formModel.industryId = val?.value || '';
            formModel.industryName = val?.label || '';
          }}
          // allowClear={false}
        ></Select>
      );
    },
    transform(data) {
      const { originLabel, value, label } = data || {};
      return { industryId: value || '', industryName: originLabel || label || '' };
    },
    label: '关注政策领域',
  },
  {
    field: 'remark',
    component: 'InputTextArea',
    label: '备注',
  },
  // {
  //   field: 'member',
  //   component: 'Switch',
  //   label: '会员',
  //   defaultValue: false,
  // },
];
/**
 * @description 更新用户密码
 */
export const updatePswSchemas: FormSchema[] = [
  {
    field: 'password',
    component: 'Input',
    label: '新密码',
    rules: [{ required: true, type: 'string' }],
  },
];
