import { reactive, watch } from 'vue';
import { debounce } from 'lodash-es';
import { getEntityNameAndCode } from '@/api/middleground';

export const useCustomerListHooks = () => {
  /**  */
  let lastFetchId = 0;
  /** 公司远程搜索结果 */
  const entityNameState = reactive<{
    data: {
      label: string;
      value: string;
    }[];
    fetching: boolean;
    value: any;
  }>({
    data: [],
    fetching: false,
    value: [],
  });

  /**
   * 公司名称远程搜索
   * @param value 公司关键词
   */
  const fetchEntityName = debounce((value) => {
    lastFetchId += 1;
    const fetchId = lastFetchId;
    entityNameState.data = [];
    entityNameState.fetching = true;
    getEntityNameAndCode({ entityName: value }).then((data) => {
      if (fetchId !== lastFetchId) {
        // for fetch callback order
        return;
      }
      // const _data = data.items.map((item) => ({
      //   label: item.name,
      //   value: item.creditCode,
      // }));
      entityNameState.data = data.items.map((item) => ({
        label: item.name,
        value: item.creditCode,
      }));
      entityNameState.fetching = false;
    });
  }, 300);

  watch(entityNameState.value, () => {
    entityNameState.data = [];
    entityNameState.fetching = false;
  });

  return {
    entityNameState,
    fetchEntityName,
  };
};
