import { computed } from 'vue';
import { Tag, Select, Spin } from 'ant-design-vue';
import type { TableColumn } from '@/components/core/dynamic-table';
import type { SchemasFromVO } from './type';
import { useDictStore } from '@/store/modules/dict.ts';
export type TableListItem = SchemasFromVO;
export type TableColumnItem = TableColumn<TableListItem>;
const { dictPending, showDictLabel, dictData } = useDictStore();

const newsType = computed(() => dictData['news_type']);

export const baseColumns: TableColumnItem[] = [
  {
    title: '排序',
    dataIndex: 'sort',
    width: 100,
    hideInSearch: true,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 100,
    ellipsis: true,
    formItemProps: {
      labelWidth: 120,
      component: ({ formModel, field }) => {
        return (
          <Select
            placeholder="请选择类型"
            v-modle:value={formModel[field]}
            options={newsType.value}
          ></Select>
        );
      },
    },
    customRender: ({ record }) => (
      <Spin spinning={dictPending['news_type']} size="small">
        <a-tag color="blue">{showDictLabel('news_type', String(record.type))}</a-tag>
      </Spin>
    ),
  },
  {
    title: '标题',
    dataIndex: 'title',
    width: 180,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 80,
    formItemProps: {
      component: 'Select',
      componentProps: {
        options: [
          {
            label: '启用',
            value: 0,
          },
          {
            label: '禁用',
            value: 1,
          },
        ],
      },
    },
    customRender: ({ record }) => {
      const enable = ~~record.status === 1;
      return <Tag color={enable ? 'red' : 'green'}>{enable ? '停用' : '启用'}</Tag>;
    },
  },
  {
    title: '发布时间',
    dataIndex: 'createTime',
    width: 100,
    hideInSearch: true,
  },
  {
    title: '发布人',
    dataIndex: 'tenantCreateBy',
    width: 100,
    hideInSearch: true,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 100,
    hideInSearch: true,
  },
  {
    title: '更新发布人',
    dataIndex: 'tenantUpdateBy',
    width: 100,
    hideInSearch: true,
  },
  {
    title: '来源',
    dataIndex: 'source',
    width: 100,
    hideInSearch: true,
  },
];
