import { computed } from 'vue';
import { Select } from 'ant-design-vue';

import type { FormSchema } from '@/components/core/schema-form/';
import type { SchemasFromVO } from './type';
import RichTextEditor from '@/components/basic/rich-text-editor/RichTextEditor.vue';
import { useDictStore } from '@/store/modules/dict.ts';
const { dictData } = useDictStore();
const newsType = computed(() => dictData['news_type']);
type FormType = {
  industry: {
    label: string;
    value: string;
  };
  companyAndCode: {
    label: string;
    value: string;
  };
};

export const userSchemas: FormSchema<SchemasFromVO & FormType>[] = [
  {
    field: 'title',
    component: 'Input',
    label: '标题',
    rules: [{ required: true, trigger: 'blur', message: '请填写标题' }],
  },
  {
    field: 'type',
    label: '类型',
    rules: [{ required: true, trigger: 'blur', message: '请选择类型' }],
    component: ({ formModel }) => {
      return (
        <Select
          placeholder="请选择类型"
          label-in-value
          fieldNames={{
            label: 'label',
            value: 'value',
          }}
          value={formModel.type}
          options={newsType.value}
          onChange={(val: { value: number; label: string }) => {
            formModel.type = val?.value;
          }}
        ></Select>
      );
    },
  },
  {
    field: 'source',
    component: 'Input',
    label: '来源',
    rules: [{ required: true, trigger: 'blur', message: '请填写来源' }],
  },

  {
    field: 'status',
    label: '状态',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        {
          label: '启用',
          value: 0,
        },
        {
          label: '禁用',
          value: 1,
        },
      ],
    },
  },

  {
    field: 'sort',
    component: 'InputNumber',
    label: '排序',
    defaultValue: 100,
    rules: [{ required: true, trigger: 'blur', message: '请填写排序' }],
    componentProps: {
      style: {
        width: '100%',
      },
    },
  },
  {
    field: 'content',
    label: '内容',
    component: () => RichTextEditor,
    rules: [{ required: true, trigger: 'blur', message: '请填写内容' }],
  },
];
